# intro
python many_types.py

# debugging
python debugging.py
bash create_gif.sh debugging

# data model
python immutable.py
python mutable.py
python copies.py
python copy_method.py
python name_rebinding.py

# call stack
python add_one.py
python factorial.py
bash create_gif.sh factorial
python power_set.py
bash create_gif.sh power_set

# datastructures
python linked_list.py
python bin_tree.py
python hash_set.py

# configuration
python not_node_types.py
python highlight.py

# extensions
python extension_numpy.py
python extension_pandas.py

# introspection
python avltree.py
python bin_search.py
python introspect_depth.py
